
Reason for this "fork" and PyPI resurrection
--------------------------------------------

The original ``itnpy`` project has been removed from
`PyPI <https://pypi.org/project/itnpy/>`__ and
`GitHub <https://github.com/Brandhsu/itnpy>`__.
That destructive action broke some dependant packages.

It has been recovered from cached version of PyPI (through Bing) and
`this early fork <https://github.com/ishine/itnpy>`__.

Maintainer
~~~~~~~~~~

Artur Barseghyan <artur.barseghyan@gmail.com>
